@@ -67,11 +67,21 @@ def ask_questions_discovery(config, defaults):
         "DISCOVERY_MYSQL_DATABASE",
         config, 
         {"DISCOVERY_MYSQL_DATABASE": ""})
+    interactive.ask(
+        "Password:", 
+        "DISCOVERY_MYSQL_PASSWORD",
+        config, 
+        {"DISCOVERY_MYSQL_PASSWORD": ""})
     interactive.ask(
         "Username:", 
         "DISCOVERY_MYSQL_USERNAME",
         config, 
         {"DISCOVERY_MYSQL_USERNAME": ""})
+    interactive.ask(
+        "Secret key:", 
+        "DISCOVERY_SECRET_KEY",
+        config, 
+        {"DISCOVERY_SECRET_KEY": ""})
     interactive.ask(
         "Partner name:", 
         "DISCOVERY_OAUTH2_KEY",
